@@ -84,14 +84,18 @@ def _emit_dependencies_declarations(
     return "\n".join(lines), serve_vars, build_vars
 
 
-def generate_shipit(path: Path, custom_commands: CustomCommands) -> str:
-    provider_cls = detect_provider(path, custom_commands)
+def generate_shipit(path: Path, custom_commands: CustomCommands, use_provider: Optional[str] = None) -> str:
+    provider_cls = None
+    if use_provider:
+        provider_cls = next((p for p in _providers() if p.name().lower() == use_provider.lower()), None)
+    if not provider_cls:
+        provider_cls = detect_provider(path, custom_commands)
     provider = provider_cls(path, custom_commands)
 
     # Collect parts
     plan = ProviderPlan(
         serve_name=provider.serve_name(),
-        provider=provider.provider_kind(),
+        provider=provider.name(),
         platform=provider.platform(),
         mounts=provider.mounts(),
         volumes=provider.volumes(),
