@@ -28,7 +28,6 @@ class Provider(Protocol):
     def initialize(self) -> None: ...
     # Structured plan steps (no path args; use self.path)
     def serve_name(self) -> str: ...
-    def provider_kind(self) -> str: ...
     def platform(self) -> Optional[str]: ...
     def dependencies(self) -> list["DependencySpec"]: ...
     def declarations(self) -> Optional[str]: ...
@@ -92,16 +91,3 @@ class ProviderPlan:
 
 def _exists(path: Path, *candidates: str) -> bool:
     return any((path / c).exists() for c in candidates)
-
-
-def _has_dependency(pkg_json: Path, dep: str) -> bool:
-    try:
-        import json
-
-        data = json.loads(pkg_json.read_text())
-        for section in ("dependencies", "devDependencies", "peerDependencies"):
-            if dep in data.get(section, {}):
-                return True
-    except Exception:
-        return False
-    return False
