@@ -27,9 +27,6 @@ class HugoProvider(StaticFileProvider):
     def serve_name(self) -> str:
         return self.path.name
 
-    def provider_kind(self) -> str:
-        return "staticsite"
-
     def platform(self) -> Optional[str]:
         return "hugo"
 
