@@ -36,9 +36,6 @@ class LaravelProvider:
     def serve_name(self) -> str:
         return self.path.name
 
-    def provider_kind(self) -> str:
-        return "php"
-
     def platform(self) -> Optional[str]:
         return "laravel"
 
