@@ -231,9 +231,6 @@ class NodeStaticProvider(StaticFileProvider):
     def serve_name(self) -> str:
         return self.path.name
 
-    def provider_kind(self) -> str:
-        return "staticsite"
-
     def platform(self) -> Optional[str]:
         return self.static_generator.value if self.static_generator else None
 
